Crate smolvm_pack

Crate smolvm_pack 

.smolmachine packaging for smolvm.

This crate provides functionality to package an OCI image and all runtime assets into a portable .smolmachine artifact that can be pushed to a registry, distributed, and run without smolvm installed.

See [format] for the full binary format specification.

Re-exports

pub use detect::detect_packed_mode;
pub use detect::PackedMode;
pub use format::PackFooter;
pub use format::PackManifest;
pub use format::PackMode;
pub use format::SectionHeader;
pub use format::FOOTER_SIZE;
pub use format::MAGIC;
pub use format::SECTION_HEADER_SIZE;
pub use format::SECTION_MAGIC;
pub use format::SIDECAR_EXTENSION;
pub use packer::read_manifest;
pub use packer::read_manifest_from_sidecar;
pub use packer::sidecar_path_for;
pub use packer::verify_sidecar_checksum;
pub use packer::Packer;

Modules

assets
Asset collection and compression for packed binaries.
detect
Packed binary auto-detection.
extract
Asset extraction for packed binaries.
format
.smolmachine binary format specification.
packer
Binary packer for assembling packed executables.
signing
Code signing support for packed executables.

Enums

PackError
Errors that can occur during pack operations.

Type Aliases

Result
Result type for pack operations.